Intergovernmental Panel on Climate Change (IPCC)
************************************************

.. include:: _api/transport_data.ipcc.rst

References
==========

Some of these references are to documents or webpages authored not by the IPCC *per se*, but by individuals or groups connected to the United Nations Framework Convention on Climate Change (UN FCCC).
Since :mod:`transport_data` does not currently have a :mod:`.unfccc` module, they are included here.

- 2006 Guidelines for National Greenhouse Gas Inventories (`HTML <https://www.ipcc-nggip.iges.or.jp/public/2006gl/>`__) — Volume 2: Energy (`HTML <https://www.ipcc-nggip.iges.or.jp/public/2006gl/vol2.html>`__) — Chapter 3: Mobile Combustion (`PDF (en) <https://www.ipcc-nggip.iges.or.jp/public/2006gl/pdf/2_Volume2/V2_3_Ch3_Mobile_Combustion.pdf>`__).
- 2023-01 Technical handbook for developing country Parties on Preparing for implementation of the enhanced transparency framework [ETF] under the Paris Agreement (`HTML <https://unfccc.int/process-and-meetings/transparency-and-reporting/support-for-developing-countries/consultative-group-of-experts/enhanced-transparency-framework-technical-material#Technical-Handbook>`__, `PDF (en) <https://unfccc.int/sites/default/files/resource/ETF%20Handbook-Edt2_EN.pdf>`__).
- 2024-01-24 Compendium on Greenhouse Gas Baselines and Monitoring Passenger and Freight Transport (`HTML <https://unfccc.int/documents/636821>`__, `PDF (en) <https://unfccc.int/sites/default/files/resource/UNFCCC Compendium Transport Revised.pdf>`__).
